pub struct Percentage(NumericUnion<(), f32, CalcNumeric>);Expand description
A specified percentage value, either a plain value or a calc() expression.
Tuple Fields
0: NumericUnion<(), f32, CalcNumeric>Implementations
Sourceimpl Percentage
impl Percentage
Sourcepub fn new_calc(val: Box<CalcNumeric>) -> Self
pub fn new_calc(val: Box<CalcNumeric>) -> Self
Returns a new percentage calc value with the value val.
Sourcepub fn get(&self) -> Option<f32>
pub fn get(&self) -> Option<f32>
Returns the value if this is a plain (non-calc) percentage, or None otherwise.
Use resolve() to also handle resolvable calc expressions, or to_computed_value()
when computed context is available.
Sourcepub fn resolve(&self) -> Option<CSSFloat>
pub fn resolve(&self) -> Option<CSSFloat>
Returns the value if it can be resolved at parse time, including resolvable calc expressions. Returns None for calc expressions that require computed context (e.g. those using relative lengths or sibling-index()).
Sourcepub fn to_length_percentage(self) -> LengthPercentage
pub fn to_length_percentage(self) -> LengthPercentage
Returns this percentage as a LengthPercentage.
Sourcepub fn reverse(&mut self)
pub fn reverse(&mut self)
Reverses this percentage, preserving calc-ness.
For example: If it was 20%, convert it into 80%.
Sourcepub fn parse_with_clamping_mode<'i, 't>(
context: &ParserContext<'_>,
input: &mut Parser<'i, 't>,
num_context: AllowedNumericType,
) -> Result<Self, ParseError<'i>>
pub fn parse_with_clamping_mode<'i, 't>( context: &ParserContext<'_>, input: &mut Parser<'i, 't>, num_context: AllowedNumericType, ) -> Result<Self, ParseError<'i>>
Parses a specific kind of percentage.
Sourcepub fn parse_non_negative<'i, 't>(
context: &ParserContext<'_>,
input: &mut Parser<'i, 't>,
) -> Result<Self, ParseError<'i>>
pub fn parse_non_negative<'i, 't>( context: &ParserContext<'_>, input: &mut Parser<'i, 't>, ) -> Result<Self, ParseError<'i>>
Parses a percentage token, but rejects it if it’s negative.
Sourcepub fn parse_zero_to_a_hundred<'i, 't>(
context: &ParserContext<'_>,
input: &mut Parser<'i, 't>,
) -> Result<Self, ParseError<'i>>
pub fn parse_zero_to_a_hundred<'i, 't>( context: &ParserContext<'_>, input: &mut Parser<'i, 't>, ) -> Result<Self, ParseError<'i>>
Parses a percentage token, but rejects it if it’s negative or more than 100%.
Sourcepub fn clamp_to_hundred(&mut self)
pub fn clamp_to_hundred(&mut self)
Clamp to 100% if the value is over 100%.